import { Link } from 'react-router-dom';
import ListErrors from './ListErrors';
import React from 'react';
import agent from '../agent';
import { connect } from 'react-redux';
import {
  UPDATE_FIELD_AUTH,
  REGISTER,
  REGISTER_PAGE_UNLOADED
} from '../constants/actionTypes';
import swal from 'sweetalert';
import ShowIcon  from '@material-ui/icons/Visibility';
import ShowOffIcon  from '@material-ui/icons/VisibilityOff';

const mapStateToProps = state => ({ ...state.auth });

const mapDispatchToProps = dispatch => ({
  onChangeEmail: value =>
    dispatch({ type: UPDATE_FIELD_AUTH, key: 'email', value }),
  onChangePassword: value =>
    dispatch({ type: UPDATE_FIELD_AUTH, key: 'password', value }),
    onConfirmPassword: value =>
    dispatch({ type: UPDATE_FIELD_AUTH, key: 'confirmPassword', value }),
  onChangeUsername: value =>
    dispatch({ type: UPDATE_FIELD_AUTH, key: 'username', value }),
  onSubmit: (username, email, password,confirmPassword) => {
    const payload = agent.Auth.register(username, email, password,confirmPassword);
    dispatch({ type: REGISTER, payload })
  },
  onUnload: () =>
    dispatch({ type: REGISTER_PAGE_UNLOADED })
});

class Register extends React.Component {
  constructor() {
    super();
    this.state = {      
      password: true,
      confirmPassword:true      
    };
    this.changeEmail = ev => this.props.onChangeEmail(ev.target.value);
    this.changePassword = ev => this.props.onChangePassword(ev.target.value);
    this.changeConfirmPassword = ev => this.props.onConfirmPassword(ev.target.value);
    this.changeUsername = ev => this.props.onChangeUsername(ev.target.value);
    this.submitForm = (username, email, password,confirmPassword) => ev => {
      ev.preventDefault();
      
      const regex = /^\S{4,}$/;
      if (!username||!email||!password) {
        swal("All fields required")
        return null;
      }
     
      if(!regex.test(password)){
        
        swal("Password at least 4 digits! No whitespaces")
        return null;
      }
      if(password !== confirmPassword ) {
            
        swal("Passwords does not match  ")
        return null;       
      }
      this.props.onSubmit(username, email, password,confirmPassword);
    }
  }

  componentWillUnmount() {
    this.props.onUnload();
  }

  render() {
    const email = this.props.email;
    const password = this.props.password;
    const confirmPassword = this.props.confirmPassword;
    const username = this.props.username;

    return (
      <div className="auth-page">
        <div className="container page">
          <div className="row">

            <div className="col-md-6 offset-md-3 col-xs-12">
              <h1 className="text-xs-center">Sign Up</h1>
              <p className="text-xs-center">
                <Link to="/login">
                  Have an account?
                </Link>
              </p>


              <form onSubmit={this.submitForm(username, email, password,confirmPassword)}>
                <fieldset>
               
                  <fieldset className="form-group">
                    <input 
                      pattern=".{1,}"                 
                      className="form-control form-control-lg"
                      type="text"
                      placeholder="Username"
                      value={this.props.username || ""}
                      onChange={this.changeUsername} />
                  </fieldset>
                  
                  <fieldset className="form-group">
                    <input
                      className="form-control form-control-lg"
                      type="email"
                      placeholder="Email"
                      value={this.props.email || ""}
                      onChange={this.changeEmail} />
                  </fieldset>

                  <fieldset className="form-group">
                    <input
                      className="form-control form-control-lg"
                      type={this.state.password ? "password":"text" }
                      placeholder="Password"
                      value={this.props.password || ""}
                      onChange={this.changePassword} />
                    <span
                      className="hideshowbtn"
                      style={{top: 240}}
                      onMouseDown={()=> this.setState({password:!this.state.password})}>
                      {this.state.password ? <ShowOffIcon/>:<ShowIcon/>}
                    </span>
                  </fieldset>
                  <fieldset className="form-group">
            <input
              className="form-control form-control-lg"
              type={this.state.confirmPassword ? "password":"text" }
              placeholder="Confirm Password"
             value={this.props.confirmPassword }              
              onChange={this.changeConfirmPassword} />
            <span
              className="hideshowbtn" style={{top: 305}}
              onMouseDown={()=> this.setState({confirmPassword:!this.state.confirmPassword})}>
              {this.state.confirmPassword ? <ShowOffIcon/>:<ShowIcon/>}
            </span>            
          </fieldset>
                 
                  <button
                    className="btn btn-lg btn-primary pull-xs-right"
                    type="submit"
                    disabled={this.props.inProgress
                              }>
                    Sign up
                  </button>

                  <ListErrors errors={this.props.errors} />


                </fieldset>
              </form>
            </div>

          </div>
        </div>
      </div>
    );
  }
}

export default connect(mapStateToProps, mapDispatchToProps)(Register);
